<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use App\Models\User;

class AuthController extends Controller
{
    public function register(Request $request)
    {
       $fields = Validator::make($request->all(), [
    'name' => 'required|string',
    'email' => 'required|string|unique:users,email',
    'password' => 'required|string',
    'password_confirmation' => 'required|same:password',
    'vendor_id' => 'required',
]);

if ($fields->fails()) {
    return response()->json(['error' => $fields->errors()], 403);
}

$user = new User();
$user->name = $request->name;
$user->email = $request->email;
$user->password = bcrypt($request->password);
$user->vendor_id = $request->vendor_id;
// Assuming role is a string field, if it's an integer or something else, adjust accordingly
$user->role = $request->role; 
$user->save();

$token = $user->createToken('myapptoken')->plainTextToken;

$response = [
    'user' => $user,
    'token' => $token
];

return response($response, 201);

    }

    public function login(Request $request)
    {
        $fields = Validator::make($request->all(), [
            'email' => 'required|string',
            'password' => 'required|string'
        ]);

        if ($fields->fails()) {
            return response()->json(['error' => $fields->errors()], 403);
        }

        // Check email
        $user = User::where('email', $request->email)->first();

        // Check password
        if (!$user || !Hash::check($request->password, $user->password)) {
            return response([
                'message' => 'Bad creds'
            ], 401);
        }

        $token = $user->createToken('myapptoken')->plainTextToken;

        $response = [
            'user' => $user->where('id', $user->id)->first(),
            'token' => $token
        ];

        return response($response, 201);
    }
    
public function index()
{
    $users = User::with('vendor')->get();

    return response($users, 200);
}
    public function update(Request $request, $id)
    {
        $user = User::find($id);

        if (!$user) {
            return response(['message' => 'User not found'], 404);
        }

        // Validate the request data
        $fields = Validator::make($request->all(), [
            'name' => 'string',
            'email' => 'string|unique:users,email,' . $id,
            'password' => 'string',
            'vendor_id' => 'required',
            'role' => 'string',
        ]);

        if ($fields->fails()) {
            return response(['error' => $fields->errors()], 403);
        }

        // Update the user data
        $user->update($request->all());

        return response(['message' => 'User updated successfully'], 200);
    }
    
     public function delete($id)
    {
        $user = User::find($id);

        if (!$user) {
            return response(['message' => 'User not found'], 404);
        }

        $user->delete();

        return response(['message' => 'User deleted successfully'], 200);
    }
}
